@@ -6,9 +6,8 @@
   version <- read.dcf(file=system.file("DESCRIPTION", package=pkgname),
                       fields="Version")
   packageStartupMessage("This is ",paste(pkgname, version))
-  # packageStartupMessage(pkgname, " is BETA software! Please report any bugs.")
+  packageStartupMessage(pkgname, " is BETA software! Please report any bugs.")
   packageStartupMessage("The (unofficial) version name is: Kitten Mittens")
-  packageStartupMessage("For questions and issues, please see github.com/sdparsons/splithalf")
-  packageStartupMessage("There is full documentation at https://sdparsons.github.io/splithalf_documentation/")
+  packageStartupMessage("For documentation, questions, and issues, please see github.com/sdparsons/splithalf")
   packageStartupMessage("or email sam.parsons@psy.ox.ac.uk")
 }
